<?php

namespace WP_SMS\Gateway;

class smsnetgr extends \WP_SMS\Gateway
{
	private $wsdl_link = "https://sms.net.gr/index.php/api/";
	public $tariff = "https://sms.net.gr/";
	public $unitrial = false;
	public $unit;
	public $flash = "false";
	public $isflash = false;

	public function __construct()
	{
		parent::__construct();
		$this->has_key = true;
		$this->bulk_send = true;
		$this->validateNumber = "e.g. 306989921111";
	}

	public function SendSMS()
	{

		/**
		 * Modify sender number
		 *
		 * @since 3.4
		 *
		 * @param string $this ->from sender number.
		 */
		$this->from = apply_filters('wp_sms_from', $this->from);

		/**
		 * Modify Receiver number
		 *
		 * @since 3.4
		 *
		 * @param array $this ->to receiver number
		 */
		$this->to = apply_filters('wp_sms_to', $this->to);

		/**
		 * Modify text message
		 *
		 * @since 3.4
		 *
		 * @param string $this ->msg text message.
		 */
		$this->msg = apply_filters('wp_sms_msg', $this->msg);

		// Get the credit.
		$credit = $this->GetCredit();

		// Check gateway credit
		if (is_wp_error($credit)) {
			// Log the result
			$this->log($this->from, $this->msg, $this->to, $credit->get_error_message(), 'error');

			return $credit;
		}

		$bulklist = [];
		foreach ($this->to as $key => $value) {
			$number = str_replace('+', '', $value);
			$bulklist[] = $number;
		}

		$response = wp_remote_get(add_query_arg([
			'username' => $this->username,
			'api_password' => $this->password,
			'api_token' => $this->has_key,
			'bulklist' => implode(',', $bulklist),
			'message' => $this->msg,
		], $this->wsdl_link.'do'));

		// Check gateway credit
		if (is_wp_error($response)) {
			// Log the result
			$this->log($this->from, $this->msg, $this->to, $response->get_error_message(), 'error');

			return new \WP_Error('send-sms', $response->get_error_message());
		}

		$response_code = wp_remote_retrieve_response_code($response);

		if ($response_code == '200') {

			$result = $response['body'];

			// Log the result
			$this->log($this->from, $this->msg, $this->to, $result);

			/**
			 * Run hook after send sms.
			 *
			 * @since 2.4
			 *
			 * @param string $result result output.
			 */
			do_action('wp_sms_send', $result);

			return $result;
		} else {
			// Log the result
			$this->log($this->from, $this->msg, $this->to, $response['body'], 'error');

			return new \WP_Error('send-sms', $response['body']);
		}
	}

	public function GetCredit()
	{
		// Check username and password
		if (!$this->username or !$this->password) {
			return new \WP_Error('account-credit', __('API Key does not set for this gateway', 'wp-sms-pro'));
		}

		$response = wp_remote_get(add_query_arg([
			'username' => $this->username,
			'api_password' => $this->password,
		], $this->wsdl_link.'credits'));

		if (is_wp_error($response)) {
			return new \WP_Error('account-credit', $response->get_error_message());
		}

		$response_code = wp_remote_retrieve_response_code($response);

		if ($response_code == '200') {
			return $response['body'];
		} else {
			return new \WP_Error('account-credit', $response['body']);
		}
	}
}
